@@ -14,6 +14,7 @@ COLORS = {
     "magenta": "\u001b[35m",
     "cyan": "\u001b[36m",
     "white": "\u001b[37m",
+    "default": "\u001b[39m",
     "reset": "\u001b[0m",
 }
 
@@ -27,5 +28,5 @@ ON_COLORS = {
     "magenta": "\u001b[45m",
     "cyan": "\u001b[46m",
     "white": "\u001b[47m",
-    "": "",
+    "default": "\u001b[49m",
 }
